@@ -1,3 +1,3 @@
-# __all__ = ["core", "manifold", "manifold_np", "manifold_torch"]
+__all__ = ["core", "manifold", "manifold_np", "manifold_torch"]
 __author__ = 'Nachuan Xiao, Xiaoyin Hu, Xin Liu, and Kim-Chuan Toh'
 
